@@ -1,5 +1,5 @@
-# Copyright: 2001-2004 The Perl Foundation.  All Rights Reserved.
-# $Id: auto.pm 10709 2005-12-28 00:12:36Z jhoblitt $
+# Copyright: 2001-2006 The Perl Foundation.  All Rights Reserved.
+# $Id: auto.pm 11749 2006-02-26 14:37:20Z bernhard $
 
 =head1 NAME
 
@@ -9,7 +9,7 @@ config/gen/cpu/i386/auto.pl
 
 Test for MMX/SSE functionality. Creates these Config entries
 
- TEMP_generated => 'files ...'   for inclusion in platform/mem.c
+ TEMP_generated => 'files ...'   for inclusion in platform.c or platform.h
  i386_has_mmx   => 1
 
 =cut
@@ -17,6 +17,7 @@ Test for MMX/SSE functionality. Creates these Config entries
 package gen::cpu::i386::auto;
 
 use strict;
+use warnings;
 
 use Parrot::Configure::Step qw(cc_gen cc_build cc_run cc_clean);
 
@@ -26,11 +27,10 @@ sub runstep
 
     my $verbose = $conf->options->get('verbose');
 
-    my (@files) = qw( memcpy_mmx.c memcpy_sse.c );
+    my @files = qw( memcpy_mmx.c memcpy_sse.c );
     for my $f (@files) {
         print " $f " if $verbose;
-        $f =~ /memcpy_(\w+)/;
-        my $suffix = $1;
+        my ( $suffix ) = $f =~ /memcpy_(\w+)/;
         $f = "config/gen/cpu/i386/$f";
         cc_gen($f);
         eval(cc_build("-DPARROT_CONFIG_TEST"));
