@@ -1,5 +1,5 @@
 # Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-# $Id: miniparrot.pm 11662 2006-02-19 03:22:51Z jhoblitt $
+# $Id: miniparrot.pm 11744 2006-02-26 10:55:39Z bernhard $
 
 =head1 NAME
 
@@ -25,7 +25,7 @@ use base qw(Parrot::Configure::Step::Base);
 
 use Parrot::Configure::Step;
 
-$description = "Tweaking settings for miniparrot...";
+$description = 'Tweaking settings for miniparrot';
 
 @args = qw(miniparrot);
 
