@@ -1,5 +1,5 @@
 # Copyright: 2001-2005 The Perl Foundation.  All Rights Reserved.
-# $Id: progs.pm 11662 2006-02-19 03:22:51Z jhoblitt $
+# $Id: progs.pm 11744 2006-02-26 10:55:39Z bernhard $
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ use base qw(Parrot::Configure::Step::Base);
 
 use Parrot::Configure::Step ':inter';
 
-$description = 'Determining what C compiler and linker to use...';
+$description = 'Determining what C compiler and linker to use';
 
 @args = qw(ask cc cxx link ld ccflags ccwarn linkflags ldflags libs debugging
     lex yacc maintainer);
