@@ -69,8 +69,9 @@ PAST_Code = 45
 PAST_Stmt = 46
 PAST_Exp = 47
 PAST_Op = 48
-PAST_Val = 49
-PAST_Noop = 50
+PAST_Val_Strqq = 49
+PAST_Val_Num = 50
+PAST_Noop = 51
 
 class Parser(antlr.LLkParser):
     ### user action >>>
@@ -927,7 +928,8 @@ _tokenNames = [
     "PAST_Stmt", 
     "PAST_Exp", 
     "PAST_Op", 
-    "PAST_Val", 
+    "PAST_Val_Strqq", 
+    "PAST_Val_Num", 
     "PAST_Noop"
 ]
     
