@@ -5,7 +5,7 @@
 # This program is free software. It is subject to the same license
 # as the Parrot interpreter.
 #
-# $Id: Call.pm 7819 2005-04-13 00:20:52Z gregor $
+# $Id: Call.pm 10644 2005-12-24 18:06:41Z gregor $
 #
 
 use strict;
@@ -104,16 +104,7 @@ sub compile
     }
   }
 
-  if (exists $props{fn} or exists $props{fnlib}) {
-    foreach my $arg (@args) {
-      $compiler->emit("  .arg $arg");
-    }
-
-    $name =~ s/::/__/g;
-
-    $compiler->emit("  call _${name}_THUNK");
-  }
-  elsif (exists $props{op}) {
+  if (exists $props{op}) {
     my $op = $props{op};
 
 #    $self->DEBUG(0, "Calling %s%s...", $name, ($op ? ' (op $op)' : ' as op'));
@@ -128,15 +119,15 @@ sub compile
     $compiler->emit("  $name ", join(", ", @args));
   }
   else {
-#    $self->DEBUG(0, "Calling '%s' as regular sub (props = %s)...", $name, join(", ", %props));
+#    $self->DEBUG(0, "Calling '%s' as regular or NCI sub (props = %s)...", $name, join(", ", %props));
 
-    foreach my $arg (@args) {
-      $compiler->emit("  .arg $arg");
+    $name =~ s/::/__/g;
+
+    if (exists $props{fn} or exists $props{fnlib}) {
+      $name .= "_THUNK";
     }
 
-    $name =~ s/::/__/;
-
-    $compiler->emit("  call _${name}");
+    $compiler->emit("  _${name}(" . join(", ", @args) . ")");
   }
 
   return 1;
