@@ -5,7 +5,7 @@
 # This program is free software. It is subject to the same license
 # as Perl itself.
 #
-# $Id: Parser.pm 10644 2005-12-24 18:06:41Z gregor $
+# $Id: Parser.pm 12028 2006-03-26 04:31:23Z gregor $
 #
 
 use strict;
@@ -43,6 +43,7 @@ use Jako::Construct::Statement::Arithmetic;
 use Jako::Construct::Statement::Assign;
 use Jako::Construct::Statement::Bitwise;
 use Jako::Construct::Statement::Call;
+use Jako::Construct::Statement::Concat;
 use Jako::Construct::Statement::Decrement;
 use Jako::Construct::Statement::Goto;
 use Jako::Construct::Statement::Increment;
@@ -483,6 +484,25 @@ sub parse
       next;
     }
 
+    #
+    # Concat assign:
+    #
+    #   <var> <op> <value>;
+    #
+
+    if ($token->is_ident and $self->get(1)->is_concat_assign) {
+      my $block = $self->current_block;
+
+      my $ident = Jako::Construct::Expression::Value::Identifier->new($block, $token);
+      my $op    = substr($self->forth->text, 0, -1);
+      my $value = Jako::Construct::Expression::Value->new($block, $self->forth);
+
+      $self->require_semicolon;
+
+      my $concat = Jako::Construct::Statement::Concat->new($block, $ident, $ident, $op, $value);
+      next;
+    }
+
     #
     # Bitwise assigns:
     #
@@ -635,6 +655,34 @@ sub parse
       next;
     }
 
+    #
+    # Concat Operators:
+    #
+    #   <var> = <value> <op> <value>;
+    #
+
+    if ($token->is_ident
+      and $self->get(1)->is_assign
+      and $self->get(2)->is_value
+      and $self->get(3)->is_infix_concat
+      and $self->get(4)->is_value
+    ) {
+      my $block = $self->current_block();
+      my $ident = Jako::Construct::Expression::Value::Identifier->new($block, $token);
+
+      $self->require_assign;
+
+      my $left  = Jako::Construct::Expression::Value->new($block, $self->forth);
+      my $op    = $self->forth->text;
+      my $right = Jako::Construct::Expression::Value->new($block, $self->forth);
+
+      $self->require_semicolon;
+
+      my $arith = Jako::Construct::Statement::Concat->new($block, $ident, $left, $op, $right);
+
+      next;
+    }
+
     #
     # Bitwise Operators:
     #
