@@ -45,7 +45,7 @@ sub get_global {
 sub get_cond {
 	my ($parser, $expr) = @_;
 	my ($defn, $opcodes) = @{$expr};
-	if (${$opcodes}[-1]->isa("ToBoolOp")) {
+	if (scalar(@{$opcodes}) and ${$opcodes}[-1]->isa("ToBoolOp")) {
 		my $tobool = pop @{$opcodes};
 		my $new = pop @{$opcodes};
 		my $loc = pop @{$opcodes};
@@ -242,52 +242,37 @@ sub BuildVariable {
 	my ($parser, $var) = @_;
 	my @opcodes = ();
 	my $idf = shift(@{$var});
-	my $defn = $parser->YYData->{symbtab}->Lookup($idf);
-	if (defined $defn) {
-		# local variable
-		if (scalar(@{$var})) {
-			my $result = $defn;
-			my $last_key = pop @{$var};
-			foreach my $key (@{$var}) {
-				push @opcodes, @{$key->[1]};
-				my $result2 = new_tmp($parser, "pmc");
-				push @opcodes, new LocalDir($parser,
-						'result'				=>	$result2,
-				);
-				push @opcodes, new KeyedGetOp($parser,
-						'result'				=>	$result2,
-						'arg1'					=>	$result,
-						'arg2'					=>	$key->[0],
-				);
-				$result = $result2;
-			}
-			push @opcodes, @{$last_key->[1]};
-			my $assign = new KeyedSetOp($parser,
-					'arg1'					=>	$last_key->[0],
-					'arg2'					=>	undef,
-					'result'				=>	$result,
+	if (ref($idf) eq "ARRAY") {
+		my $defn = $idf->[0];
+		push @opcodes,  @{$idf->[1]};
+		my $last_key = pop @{$var};
+		my $result = $defn;
+		foreach my $key (@{$var}) {
+			push @opcodes, @{$key->[1]};
+			my $result2 = new_tmp($parser, "pmc");
+			push @opcodes, new LocalDir($parser,
+					'result'				=>	$result2,
 			);
-			return [$defn, \@opcodes, $assign];
-		} else {
-			my $assign = new AssignOp($parser,
-					'arg1'					=>	undef,
-					'result'				=>	$defn,
+			push @opcodes, new KeyedGetOp($parser,
+					'result'				=>	$result2,
+					'arg1'					=>	$result,
+					'arg2'					=>	$key->[0],
 			);
-			return [$defn, [], $assign];
+			$result = $result2;
 		}
+		push @opcodes, @{$last_key->[1]};
+		my $assign = new KeyedSetOp($parser,
+				'arg1'					=>	$last_key->[0],
+				'arg2'					=>	undef,
+				'result'				=>	$result,
+		);
+		return [$defn, \@opcodes, $assign];
 	} else {
-		my $defn = $parser->YYData->{symbtab}->LookupU($idf);
+		my $defn = $parser->YYData->{symbtab}->Lookup($idf);
 		if (defined $defn) {
-			# upvariable
+			# local variable
 			if (scalar(@{$var})) {
-				my $result = new_tmp($parser, "pmc");
-				push @opcodes, new LocalDir($parser,
-						'result'				=>	$result,
-				);
-				push @opcodes, new FindLexOp($parser,
-						'result'				=>	$result,
-						'arg1'					=>	$defn,
-				);
+				my $result = $defn;
 				my $last_key = pop @{$var};
 				foreach my $key (@{$var}) {
 					push @opcodes, @{$key->[1]};
@@ -310,39 +295,81 @@ sub BuildVariable {
 				);
 				return [$defn, \@opcodes, $assign];
 			} else {
-				my $assign = new StoreLexOp($parser,
-						'arg1'					=>	$defn,
-						'arg2'					=>	undef,
+				my $assign = new AssignOp($parser,
+						'arg1'					=>	undef,
+						'result'				=>	$defn,
 				);
 				return [$defn, [], $assign];
 			}
 		} else {
-			# global variable
-			my $global = get_global($parser);
-			push @opcodes, @{$global->[1]};
-			my $key = BuildLiteral($parser, $idf, "key");
-			push @opcodes, @{$key->[1]};
-			my $result = $global->[0];
-			foreach my $key2 (@{$var}) {
-				my $result2 = new_tmp($parser, "pmc");
-				push @opcodes, new LocalDir($parser,
-						'result'				=>	$result2,
-				);
-				push @opcodes, new KeyedGetOp($parser,
-						'result'				=>	$result2,
-						'arg1'					=>	$result,
-						'arg2'					=>	$key->[0],
-				);
-				$result = $result2;
-				$key = $key2;
+			my $defn = $parser->YYData->{symbtab}->LookupU($idf);
+			if (defined $defn) {
+				# upvariable
+				if (scalar(@{$var})) {
+					my $result = new_tmp($parser, "pmc");
+					push @opcodes, new LocalDir($parser,
+							'result'				=>	$result,
+					);
+					push @opcodes, new FindLexOp($parser,
+							'result'				=>	$result,
+							'arg1'					=>	$defn,
+					);
+					my $last_key = pop @{$var};
+					foreach my $key (@{$var}) {
+						push @opcodes, @{$key->[1]};
+						my $result2 = new_tmp($parser, "pmc");
+						push @opcodes, new LocalDir($parser,
+								'result'				=>	$result2,
+						);
+						push @opcodes, new KeyedGetOp($parser,
+								'result'				=>	$result2,
+								'arg1'					=>	$result,
+								'arg2'					=>	$key->[0],
+						);
+						$result = $result2;
+					}
+					push @opcodes, @{$last_key->[1]};
+					my $assign = new KeyedSetOp($parser,
+							'arg1'					=>	$last_key->[0],
+							'arg2'					=>	undef,
+							'result'				=>	$result,
+					);
+					return [$defn, \@opcodes, $assign];
+				} else {
+					my $assign = new StoreLexOp($parser,
+							'arg1'					=>	$defn,
+							'arg2'					=>	undef,
+					);
+					return [$defn, [], $assign];
+				}
+			} else {
+				# global variable
+				my $global = get_global($parser);
+				push @opcodes, @{$global->[1]};
+				my $key = BuildLiteral($parser, $idf, "key");
 				push @opcodes, @{$key->[1]};
+				my $result = $global->[0];
+				foreach my $key2 (@{$var}) {
+					my $result2 = new_tmp($parser, "pmc");
+					push @opcodes, new LocalDir($parser,
+							'result'				=>	$result2,
+					);
+					push @opcodes, new KeyedGetOp($parser,
+							'result'				=>	$result2,
+							'arg1'					=>	$result,
+							'arg2'					=>	$key->[0],
+					);
+					$result = $result2;
+					$key = $key2;
+					push @opcodes, @{$key->[1]};
+				}
+				my $assign = new KeyedSetOp($parser,
+						'arg1'					=>	$key->[0],
+						'arg2'					=>	undef,
+						'result'				=>	$result,
+				);
+				return [$result, \@opcodes, $assign];
 			}
-			my $assign = new KeyedSetOp($parser,
-					'arg1'					=>	$key->[0],
-					'arg2'					=>	undef,
-					'result'				=>	$result,
-			);
-			return [$result, \@opcodes, $assign];
 		}
 	}
 }
@@ -398,39 +425,68 @@ sub BuildAssigns {
 	return \@opcodes1;
 }
 
+sub BuildCallVararg {
+	my ($parser) = @_;
+	my $result;
+	my @opcodes = ();
+	my $nil = BuildLiteral($parser, 'nil', 'nil');
+	push @opcodes, @{$nil->[1]};
+	$result = new_tmp($parser, "pmc");
+	push @opcodes, new LocalDir($parser,
+			'result'				=>	$result,
+	);
+	push @opcodes, new AssignOp($parser,
+			'result'				=>	$result,
+			'arg1'					=>	$nil->[0],
+	);
+	my $argv = new defn("vararg", "local", "pmc");
+	my $fct = new defn("mkarg", "util");
+	push @opcodes, new CallOp($parser,
+			'result'				=>	[$result],
+			'arg1'					=>	$fct,
+			'arg2'					=>	[$argv],
+	);
+	return [$result, \@opcodes];
+}
+
 sub BuildCallVariable {
 	my ($parser, $var) = @_;
 	my $result;
 	my @opcodes = ();
 	my $idf = shift(@{$var});
-	my $defn = $parser->YYData->{symbtab}->Lookup($idf);
-	if (defined $defn) {
-		$result = $defn;
+	if (ref($idf) eq "ARRAY") {
+		$result = $idf->[0];
+		push @opcodes, @{$idf->[1]};
 	} else {
-		$defn = $parser->YYData->{symbtab}->LookupU($idf);
+		my $defn = $parser->YYData->{symbtab}->Lookup($idf);
 		if (defined $defn) {
-			$result = new_tmp($parser, "pmc");
-			push @opcodes, new LocalDir($parser,
-					'result'				=>	$result,
-			);
-			push @opcodes, new FindLexOp($parser,
-					'result'				=>	$result,
-					'arg1'					=>	$defn,
-			);
-		} else { 
-			my $global = get_global($parser);
-			push @opcodes, @{$global->[1]};
-			my $key = BuildLiteral($parser, $idf, "key");
-			push @opcodes, @{$key->[1]};
-			$result = new_tmp($parser, "pmc");
-			push @opcodes, new LocalDir($parser,
-					'result'				=>	$result,
-			);
-			push @opcodes, new KeyedGetOp($parser,
-					'result'				=>	$result,
-					'arg1'					=>	$global->[0],
-					'arg2'					=>	$key->[0],
-			);
+			$result = $defn;
+		} else {
+			$defn = $parser->YYData->{symbtab}->LookupU($idf);
+			if (defined $defn) {
+				$result = new_tmp($parser, "pmc");
+				push @opcodes, new LocalDir($parser,
+						'result'				=>	$result,
+				);
+				push @opcodes, new FindLexOp($parser,
+						'result'				=>	$result,
+						'arg1'					=>	$defn,
+				);
+			} else { 
+				my $global = get_global($parser);
+				push @opcodes, @{$global->[1]};
+				my $key = BuildLiteral($parser, $idf, "key");
+				push @opcodes, @{$key->[1]};
+				$result = new_tmp($parser, "pmc");
+				push @opcodes, new LocalDir($parser,
+						'result'				=>	$result,
+				);
+				push @opcodes, new KeyedGetOp($parser,
+						'result'				=>	$result,
+						'arg1'					=>	$global->[0],
+						'arg2'					=>	$key->[0],
+				);
+			}
 		}
 	}
 	foreach my $key (@{$var}) {
@@ -449,6 +505,25 @@ sub BuildCallVariable {
 	return [$result, \@opcodes];
 }
 
+sub BuildCallMethod {
+	my ($parser, $obj, $meth, $args) = @_;
+	my @opcodes = ();
+	my $key = BuildLiteral($parser, $meth, "key");
+	push @opcodes, @{$key->[1]};
+	my $result = new_tmp($parser, "pmc");
+	push @opcodes, new LocalDir($parser,
+			'result'				=>	$result,
+	);
+	push @opcodes, new KeyedGetOp($parser,
+			'result'				=>	$result,
+			'arg1'					=>	$obj->[0],
+			'arg2'					=>	$key->[0],
+	);
+	my $fct = [$result, \@opcodes];
+	unshift @{$args}, $obj;
+	return BuildCallFunction($parser, $fct, $args);
+}
+
 sub BuildCallFunction {
 	my ($parser, $fct, $args) = @_;
 	my $result;
@@ -456,7 +531,11 @@ sub BuildCallFunction {
 	my @params = ();
 	my @returns = ();
 	for my $arg (@{$args}) {
-		push @opcodes, @{$arg->[1]};
+		if (scalar @{$arg->[1]}) {
+			push @opcodes, @{$arg->[1]};
+		} else {
+			push @opcodes, new NoOp($parser);
+		}
 		push @params, $arg->[0];
 	}
 	if (scalar(@opcodes) and $opcodes[-1]->isa("CallOp")) {
@@ -499,6 +578,7 @@ sub BuildUnop {
 	my ($parser, $op, $expr) = @_;
 	my %type = (
 		"-"		=> "number",
+		"#"		=> "number",
 		"not"	=> "boolean",
 	);
 	my %opcode = (
@@ -515,11 +595,19 @@ sub BuildUnop {
 			'result'				=>	$result,
 			'arg1'					=>	".Lua" . ucfirst($type{$op}),
 	);
-	push @opcodes, new UnaryOp($parser,
-			'op'					=>	$opcode{$op},
-			'arg1'					=>	$expr->[0],
-			'result'				=>	$result,
-	);
+	if ($op eq "#") {
+		push @opcodes, new CallMethOp($parser,
+				'result'				=>	[$result],
+				'arg1'					=>	"len",
+				'arg2'					=>	[$expr->[0]],
+		);
+	} else {
+		push @opcodes, new UnaryOp($parser,
+				'op'					=>	$opcode{$op},
+				'arg1'					=>	$expr->[0],
+				'result'				=>	$result,
+		);
+	}
 	return [$result, \@opcodes];
 }
 
@@ -531,6 +619,7 @@ sub BuildBinop {
 		"*"		=> "number",
 		"/"		=> "number",
 		"^"		=> "number",
+		"%"		=> "number",
 		".."	=> "string",
 	);
 	my %opcode = (
@@ -539,6 +628,7 @@ sub BuildBinop {
 		"*"		=> "mul",
 		"/"		=> "div",
 		"^"		=> "pow",
+		"%"		=> "mod",
 		".."	=> "concat",
 	);
 	my @opcodes = ();
@@ -783,24 +873,27 @@ sub BuildRepeat {
 sub BuildForNum {
 	my ($parser, $var, $e_start, $e_limit, $e_step, $block) = @_;
 	my @opcodes = ();
-	push @opcodes, @{$var->[1]};
 	unless (defined $e_step) {
 		$e_step = BuildLiteral($parser, 1, "number");
 	}
 	push @opcodes, @{$e_start->[1]};
 	push @opcodes, @{$e_limit->[1]};
 	push @opcodes, @{$e_step->[1]};
-	my $limit = new_tmp($parser, "pmc", "number");
+	my $_var = new_tmp($parser, "pmc", "number");
 	push @opcodes, new LocalDir($parser,
-			'result'				=>	$limit,
+			'result'				=>	$_var,
 	);
-	my $step = new_tmp($parser, "pmc", "number");
+	my $_limit = new_tmp($parser, "pmc", "number");
 	push @opcodes, new LocalDir($parser,
-			'result'				=>	$step,
+			'result'				=>	$_limit,
+	);
+	my $_step = new_tmp($parser, "pmc", "number");
+	push @opcodes, new LocalDir($parser,
+			'result'				=>	$_step,
 	);
 	my $fct = new defn("checkforloop", "util");
 	push @opcodes, new CallOp($parser,
-			'result'				=>	[ $var->[0], $limit, $step ],
+			'result'				=>	[ $_var, $_limit, $_step ],
 			'arg1'					=>	$fct,
 			'arg2'					=>	[ $e_start->[0], $e_limit->[0], $e_step->[0] ],
 	);
@@ -812,16 +905,16 @@ sub BuildForNum {
 	my $zero = BuildLiteral($_[0], 0, "number");
 	push @opcodes, @{$zero->[1]};
 	push @opcodes, new BranchUnlessOp($parser,
-			'arg1'					=>	$step,
+			'arg1'					=>	$_step,
 			'op'					=>	">",
 			'arg2'					=>	$zero->[0],
 			'result'				=>	$lbl_or,
 	);
 	my $lbl_end = new_label($parser);
 	push @opcodes, new BranchUnlessOp($parser,
-			'arg1'					=>	$var->[0],
+			'arg1'					=>	$_var,
 			'op'					=>	"<=",
-			'arg2'					=>	$limit,
+			'arg2'					=>	$_limit,
 			'result'				=>	$lbl_end,
 	);
 	my $lbl_blk = new_label($parser);
@@ -832,14 +925,19 @@ sub BuildForNum {
 			'arg1'					=>	$lbl_or,
 	);
 	push @opcodes, new BranchUnlessOp($parser,
-			'arg1'					=>	$var->[0],
+			'arg1'					=>	$_var,
 			'op'					=>	">=",
-			'arg2'					=>	$limit,
+			'arg2'					=>	$_limit,
 			'result'				=>	$lbl_end,
 	);
 	push @opcodes, new LabelOp($parser,
 			'arg1'					=>	$lbl_blk,
 	);
+	push @opcodes, @{$var->[1]};
+	push @opcodes, new AssignOp($parser,
+			'result'				=>	$var->[0],
+			'arg1'					=>	$_var,
+	);
 	foreach my $op (@{$block}) {
 		if ($op and $op->isa('BranchOp')) {
 			if ($op->{result} eq 'break') {
@@ -850,9 +948,9 @@ sub BuildForNum {
 	push @opcodes, @{$block};
 	push @opcodes, new BinaryOp($parser,
 			'op'					=>	"add",
-			'arg1'					=>	$var->[0],
-			'arg2'					=>	$step,
-			'result'				=>	$var->[0],
+			'arg1'					=>	$_var,
+			'arg2'					=>	$_step,
+			'result'				=>	$_var,
 	);
 	push @opcodes, new BranchOp($parser,
 			'result'				=>	$lbl_loop,
@@ -869,14 +967,12 @@ sub BuildForList {
 	my @opcodes2 = ();
 	my @opcodes3 = ();
 	my @params1 = ();
-	my @params2 = ();
 	my @return1 = ();
-	my @return2 = ();
 	my $var1 = ${$vars}[0];
 	my $nil = BuildLiteral($parser, "nil", "nil");
 	push @opcodes1, @{$nil->[1]};
-	for my $var (@{$vars}) {
-		push @opcodes1, @{$var->[1]};
+	for (@{$vars}) {
+		push @opcodes1, @{$_->[1]};
 	}
 	my $expr = shift @{$exprs};
 	my $iter = new_tmp($parser, "pmc");
@@ -919,39 +1015,45 @@ sub BuildForList {
 		);
 		$expr = shift @{$exprs};
 	}
+	my $var = new_tmp($parser, "pmc");
+	push @opcodes1, new LocalDir($parser,
+			'result'				=>	$var,
+	);
 	if (        scalar(@{$exprs}) == 0
 			and scalar(@{$expr->[1]}) != 0 
 			and ${$expr->[1]}[-1]->isa("CallOp") ) {
-		my $callop = ${$expr->[1]}[-1];
-		unshift @{$callop->{result}}, @return1;
-		push @opcodes2, @{$expr->[1]};
-		push @opcodes2, new AssignOp($parser,
-				'result'				=>	$var1->[0],
-				'arg1'					=>	${$callop->{result}}[-1],
+		push @opcodes1, new AssignOp($parser,
+				'result'				=>	$var,
+				'arg1'					=>	$nil->[0],
 		);
+		push @return1, $var;
 	} else {
 		push @opcodes2, @{$expr->[1]};
-		my $assign = $var1->[2];
-		if ($assign->isa("AssignOp")) {
-			$assign->configure(
-					'arg1'					=>	$expr->[0],
-			);
-		} else {
-			$assign->configure(
-					'arg2'					=>	$expr->[0],
-			);
-		}
-		push @opcodes3, $assign;
+		push @opcodes3, new AssignOp($parser,
+				'result'				=>	$var,
+				'arg1'					=>	$expr->[0],
+		);
+		$expr = shift @{$exprs};
+	}
+	if (        scalar(@{$exprs}) == 0
+			and scalar(@{$expr->[1]}) != 0 
+			and ${$expr->[1]}[-1]->isa("CallOp") ) {
+		push @opcodes2, @{$expr->[1]};
+		my $callop = pop @opcodes2;
+		my $ass = pop @opcodes2;
+		my $decl = pop @opcodes2;
+		$callop->{result} = \@return1;
+		push @opcodes2, $callop;
 	}
 	push @opcodes1, @opcodes2, @opcodes3;
 	my $lbl_loop = new_label($parser);
 	push @opcodes1, new LabelOp($parser,
 			'arg1'					=>	$lbl_loop,
 	);
-	push @params2, $state;
-	push @params2, $var1->[0];
+	my @params2 = ($state, $var);
+	my @return2 = ();
 	@opcodes2 = ();
-	for my $var (@{$vars}) {
+	for (@{$vars}) {
 		my $result = new_tmp($parser, "pmc");
 		push @opcodes1, new LocalDir($parser,
 				'result'				=>	$result,
@@ -962,7 +1064,7 @@ sub BuildForList {
 		);                                  
 		push @return2, $result;
 		push @opcodes2, new AssignOp($parser,
-				'result'				=>	$var->[0],
+				'result'				=>	$_->[0],
 				'arg1'					=>	$result,
 		);
 	}
@@ -972,11 +1074,15 @@ sub BuildForList {
 			'arg2'					=>	\@params2,
 	);
 	push @opcodes1, @opcodes2;
+	push @opcodes1, new AssignOp($parser,
+			'result'				=>	$var,
+			'arg1'					=>	$var1->[0],
+	);                                  
 	my $lbl_end = new_label($parser);
 	push @opcodes1, new BranchIfOp($parser,
 			'arg1'					=>	$nil->[0],
 			'op'					=>	"==",
-			'arg2'					=>	$var1->[0],
+			'arg2'					=>	$var,
 			'result'				=>	$lbl_end,
 	);
 	foreach my $op (@{$block}) {
@@ -1010,7 +1116,11 @@ sub BuildReturn {
 	my @opcodes = ();
 	my @returns = ();
 	for my $expr (@{$exprs}) {
-		push @opcodes, @{$expr->[1]};
+		if (scalar @{$expr->[1]}) {
+			push @opcodes, @{$expr->[1]};
+		} else {
+			push @opcodes, new NoOp($parser);
+		}
 		push @returns, $expr->[0];
 	}
 	if (scalar(@opcodes) and $opcodes[-1]->isa("CallOp")) {
@@ -1029,29 +1139,15 @@ sub  BuildParam {
 	my @opcodes1 = ();
 	my @opcodes2 = ();
 	my $defn;
-	my $name;
 	if ($idf eq "...") {
-		my $argv = new defn("argv", "local", "pmc");
+		$defn = new defn("vararg", "local", "pmc");
 		push @opcodes1, new ParamDir($parser,
 				'prolog'				=>	1,
-				'result'				=>	$argv,
+				'result'				=>	$defn,
 				'pragma'				=>	":slurpy",
 		);
-		$name = "var_arg";
-		$defn = new defn($name, "local", "pmc", undef, "arg");
-		push @opcodes1, new LocalDir($parser,
-				'prolog'				=>	1,
-				'result'				=>	$defn,
-		);
-		my $fct = new defn("mkarg", "util");
-		push @opcodes1, new CallOp($parser,
-				'prolog'				=>	1,
-				'result'				=>	[$defn],
-				'arg1'					=>	$fct,
-				'arg2'					=>	[$argv],
-		);
 	} else {
-		$name = "var_" . scalar(@{$parser->YYData->{scope}}) . "_" . $idf;
+		my $name = "var_" . scalar(@{$parser->YYData->{scope}}) . "_" . $idf;
 		$defn = new defn($name, "local", "pmc", undef, $idf);
 		push @opcodes1, new ParamDir($parser,
 				'prolog'				=>	1,
@@ -1079,15 +1175,24 @@ sub  BuildParam {
 				'prolog'				=>	1,
 				'arg1'					=>	$lbl,
 		);
+		$parser->YYData->{symbtab}->Insert($defn);
 	}
-	$parser->YYData->{symbtab}->Insert($defn);
 	return [$defn, \@opcodes1, \@opcodes2];
 }
 
+sub PrepareMethod {
+	my ($parser) = @_;
+	$parser->YYData->{self} = BuildParam($parser, "self");
+}
+
 sub BuildFunctionBody {
 	my ($parser, $params, $block) = @_;
 	my @opcodes1 = ();
 	my @opcodes2 = ();
+	if ($parser->YYData->{self}) {
+		unshift @{$params}, $parser->YYData->{self};
+		$parser->YYData->{self} = undef;
+	}
 	my $fct = new_fct($parser);
 	push @opcodes2, new SubDir($parser,
 			'prolog'				=>	1,
@@ -1098,7 +1203,7 @@ sub BuildFunctionBody {
 		push @opcodes2, @{$param->[1]};
 	}
 	if (        scalar(@{$params}) != 0 
-			and !${${${$params}[-1]}[1]}[-1]->isa("CallOp") ) {
+			and !exists ${${${$params}[-1]}[1]}[-1]->{pragma} ) {
 		my $extra = new defn("extra", "local", "pmc");
 		push @opcodes2, new ParamDir($parser,
 				'prolog'				=>	1,
