@@ -1,5 +1,5 @@
 # Copyright: 2004 The Perl Foundation.  All Rights Reserved.
-# $Id: Ops.pm 5757 2004-03-27 22:23:02Z mikescott $
+# $Id: Ops.pm 10620 2005-12-22 07:48:49Z fperrad $
 
 =head1 NAME
 
@@ -39,11 +39,11 @@ sub new
 	return $self->SUPER::new(
 		'Ops', 'ops.html', '',
 		$self->new_group('Tools', '',
-			$self->new_item('', 'build_tools/ops2c.pl'),
-			$self->new_item('', 'ops/ops.num'),
-			$self->new_item('', 'build_tools/ops2pm.pl'),
+			$self->new_item('', 'tools/build/ops2c.pl'),
+			$self->new_item('', 'src/ops/ops.num'),
+			$self->new_item('', 'tools/build/ops2pm.pl'),
 		),
-		$self->new_group('Op Libs', '', 'ops'),
+		$self->new_group('Op Libs', '', 'src/ops'),
 	);
 }
 
