@@ -1,6 +1,6 @@
 /*
-Copyright: 2001-2005 The Perl Foundation.  All Rights Reserved.
-$Id: exec_start.c 10933 2006-01-06 01:43:24Z particle $
+Copyright: 2001-2006 The Perl Foundation.  All Rights Reserved.
+$Id: exec_start.c 12064 2006-03-28 19:08:48Z bernhard $
 
 =head1 NAME
 
@@ -36,51 +36,7 @@ opcode_t* run_compiled(Interp *interpreter,
 
 /*
 
-=item C<static void
-setup_argv(Interp *interpreter, int argc, char ** argv)>
-
-Stolen from F<embed.c>.
-
-=cut
-
-*/
-
-static void
-setup_argv(Interp *interpreter, int argc, char ** argv)
-{
-    INTVAL i;
-    PMC *userargv;
-
-    if (Interp_debug_TEST(interpreter, PARROT_START_DEBUG_FLAG)) {
-        PIO_eprintf(interpreter,
-        "*** Parrot VM: Setting up ARGV array in P5.  Current argc: %d ***\n",
-                argc);
-    }
-
-    userargv = pmc_new_noinit(interpreter, enum_class_SArray);
-    /* immediately anchor pmc to root set */
-    REG_PMC(5) = userargv;
-    VTABLE_set_pmc_keyed_int(interpreter, interpreter->iglobals,
-            (INTVAL)IGLOBALS_ARGV_LIST, userargv);
-    VTABLE_init(interpreter, userargv);
-    VTABLE_set_integer_native(interpreter, userargv, argc);
-
-    for (i = 0; i < argc; i++) {
-        /* Run through argv, adding everything to @ARGS. */
-        STRING *arg = string_make(interpreter, argv[i], strlen(argv[i]),
-                                  "binary", PObj_external_FLAG);
-
-        if (Interp_debug_TEST(interpreter, PARROT_START_DEBUG_FLAG)) {
-            PIO_eprintf(interpreter, "\t%vd: %s\n", i, argv[i]);
-        }
-
-        VTABLE_push_string(interpreter, userargv, arg);
-    }
-}
-
-/*
-
-=item C<int main(int argc, char **argv)>
+=item C<int main(int argc, char * argv[])>
 
 The run-loop.
 
@@ -89,36 +45,34 @@ The run-loop.
 */
 
 int
-main(int argc, char **argv) {
-    long *opp;
-    int dummy_var;
-    Interp *     interpreter;
-    struct PackFile *          pf;
-    opcode_t *code_start;
-    INTVAL i;
-    PMC *userargv;
-    extern char *program_code;
-    extern long opcode_map;
-    extern int bytecode_offset;
+main(int argc, char * argv[])
+{
+    /* long *             opp; */
+    Interp *           interpreter;
+    struct PackFile *  pf;
+    opcode_t *         code_start;
+    extern char *      program_code;
+    /* extern long        opcode_map; */
+    /* extern int         bytecode_offset; */
 #if defined(JIT_CGP)
-    extern void * exec_prederef_code;
+    extern void *      exec_prederef_code;
 #endif
-    extern int Parrot_exec_run;
-    extern struct PackFile_Constant *exec_const_table;
-    extern struct PackFile_Constant const_table;
+    /* extern int        Parrot_exec_run; */
+    /* extern struct PackFile_Constant *exec_const_table; */
+    /* extern struct PackFile_Constant const_table; */
     extern Interp interpre;
 
     /* s. exec.c */
-    Parrot_exec_run = 1;
+    /* Parrot_exec_run = 1; */
     /* s. packfile.c (PackFile_ConstTable_unpack()) */
-    exec_const_table = &const_table;
+    /* exec_const_table = &const_table; */
     interpreter = Parrot_new(NULL);
     if (!interpreter) {
         return 1;
     }
     Parrot_init(interpreter);
 
-    run_native = run_compiled;
+    /* run_native = run_compiled; */
     /* TODO make also a shared variant of PackFile_new */
     pf = PackFile_new(interpreter, 0);
 
@@ -128,30 +82,32 @@ main(int argc, char **argv) {
         printf( "Can't unpack.\n" );
         return 1;
     }
-    PackFile_fixup_subs(interpreter, PBC_PBC, NULL);
     Parrot_loadbc(interpreter, pf);
-    setup_argv(interpreter, argc, argv);
+    PackFile_fixup_subs(interpreter, PBC_PBC, NULL);
 
     /* opcode_map has the offset of each opcode in the compiled code
      * this modifies it to be address of the opcode.
      */
+    /*
     opp = &opcode_map;
     for (i = 0; i < (int)interpre.code->base.size; i++) {
         opp[i] += (long)run_compiled;
     }
+    */
 
 #if defined(JIT_CGP)
     exec_init_prederef(interpreter, &exec_prederef_code);
 #endif
-    Parrot_set_run_core(interpreter, PARROT_EXEC_CORE);
+    /* Parrot_set_run_core(interpreter, PARROT_EXEC_CORE); 
     interpreter->code->base.data =
         (opcode_t *)&((&program_code)[bytecode_offset]);
-    Parrot_exec_run = 0;
-    runops(interpreter, 0);
+    Parrot_exec_run = 0; */
+    Parrot_runcode(interpreter, argc, argv);
     /*
         run_compiled(interpreter,
             (opcode_t *)&((&program_code)[bytecode_offset]));
      */
+    Parrot_exit(0);
     exit(0);
 }
 
@@ -162,7 +118,7 @@ main(int argc, char **argv) {
 =head1 SEE ALSO
 
 F<include/parrot/exec.h>, F<include/parrot/exec_save.h>, F<src/exec.c>
-and F<src/exec_start.c>.
+and F<compilers/imcc/main.c>.
 
 =head1 HISTORY
 
