@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: interpreter.c 11571 2006-02-16 08:19:11Z leo $
+$Id: interpreter.c 11742 2006-02-25 23:19:54Z leo $
 
 =head1 NAME
 
@@ -374,7 +374,7 @@ init_prederef(Interp *interpreter, int which)
 	CONTEXT(interpreter->ctx)->pred_offset = pc - (opcode_t*)temp;
 
         /* fill with the prederef__ opcode function */
-        if (which == PARROT_SWITCH_CORE)
+        if (which == PARROT_SWITCH_CORE || which == PARROT_SWITCH_JIT_CORE )
             pred_func = (void*) CORE_OPS_prederef__;
         else
             pred_func = ((void **)
