@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: objects.c 11500 2006-02-10 17:06:23Z coke $
+$Id: objects.c 12083 2006-04-01 11:33:22Z leo $
 
 =head1 NAME
 
@@ -72,6 +72,11 @@ rebuild_attrib_stuff(Interp* interpreter, PMC *class)
     PMC *orig_class = class;
 #endif
 
+    /* attrib count isn't set yet, a GC causedd by concat could
+     * corrupt data under construction
+     */
+    Parrot_block_DOD(interpreter);
+
     class_slots = PMC_data(class);
     attr_offset_hash = pmc_new(interpreter, enum_class_Hash);
     set_attrib_num(class, class_slots, PCD_ATTRIBUTES, attr_offset_hash);
@@ -135,6 +140,7 @@ rebuild_attrib_stuff(Interp* interpreter, PMC *class)
     assert(class == orig_class);
     /* And note the totals */
     ATTRIB_COUNT(class) = cur_offset;
+    Parrot_unblock_DOD(interpreter);
 }
 
 /*
@@ -165,9 +171,9 @@ create_deleg_pmc_vtable(Interp *interpreter, PMC *class, STRING *class_name)
     vtable_pmc = get_attrib_num((SLOTTYPE*)PMC_data(class),
             PCD_OBJECT_VTABLE);
     vtable = PMC_struct_val(vtable_pmc);
-    deleg_pmc_vtable = Parrot_base_vtables[enum_class_deleg_pmc];
-    object_vtable = Parrot_base_vtables[enum_class_ParrotObject];
-    delegate_vtable = Parrot_base_vtables[enum_class_delegate];
+    deleg_pmc_vtable = interpreter->vtables[enum_class_deleg_pmc];
+    object_vtable = interpreter->vtables[enum_class_ParrotObject];
+    delegate_vtable = interpreter->vtables[enum_class_delegate];
 
     memset(&meth_str, 0, sizeof(meth_str));
     meth_str.encoding = Parrot_fixed_8_encoding_ptr;
@@ -272,10 +278,9 @@ Parrot_single_subclass(Interp* interpreter, PMC *base_class,
     /*
      * ParrotClass is the baseclass anyway, so build just a new class
      */
-    if (base_class == Parrot_base_vtables[enum_class_ParrotClass]->class) {
-        PMC* class = pmc_new(interpreter, enum_class_ParrotClass);
-        Parrot_new_class(interpreter, class, child_class_name);
-        return class;
+    if (base_class == interpreter->vtables[enum_class_ParrotClass]->class) {
+        return pmc_new_init(interpreter, enum_class_ParrotClass, 
+                (PMC*)child_class_name);
     }
     parent_is_class = PObj_is_class_TEST(base_class);
 
@@ -319,7 +324,7 @@ Parrot_single_subclass(Interp* interpreter, PMC *base_class,
     VTABLE_unshift_pmc(interpreter, mro, child_class);
 
     /* But we have no attributes of our own. Yet */
-    temp_pmc = pmc_new(interpreter, enum_class_Array);
+    temp_pmc = pmc_new(interpreter, enum_class_ResizablePMCArray);
     set_attrib_num(child_class, child_class_array, PCD_CLASS_ATTRIBUTES,
             temp_pmc);
 
@@ -377,10 +382,9 @@ Parrot_new_class(Interp* interpreter, PMC *class, STRING *class_name)
     VTABLE_push_pmc(interpreter, mro, class);
 
     /* no attributes yet
-     * TODO used a core array
      */
     set_attrib_num(class, class_array, PCD_CLASS_ATTRIBUTES,
-            pmc_new(interpreter, enum_class_Array));
+            pmc_new(interpreter, enum_class_ResizablePMCArray));
 
     /* Set the classname */
     classname_pmc = pmc_new(interpreter, enum_class_String);
@@ -412,11 +416,11 @@ Parrot_class_lookup(Interp* interpreter, STRING *class_name)
                 (Hash*) PMC_struct_val(interpreter->class_hash), class_name);
     if (b) {
         INTVAL type = PMC_int_val((PMC*)b->value);
-        PMC *pmc = Parrot_base_vtables[type]->class;
+        PMC *pmc = interpreter->vtables[type]->class;
         assert(pmc);
 #if 0
         if (!pmc) {
-            pmc = Parrot_base_vtables[type]->class =
+            pmc = interpreter->vtables[type]->class =
                 pmc_new_noinit(interpreter, type);
         }
 #endif
@@ -448,6 +452,7 @@ parrot_class_register(Interp* interpreter, STRING *class_name,
     INTVAL new_type;
     VTABLE *new_vtable, *parent_vtable;
     PMC *vtable_pmc;
+    PMC *ns, *top; 
 
     /*
      * register the class in the PMCs name class_hash
@@ -482,7 +487,27 @@ parrot_class_register(Interp* interpreter, STRING *class_name,
     new_class->vtable = new_vtable;
 
     /* Put our new vtable in the global table */
-    Parrot_base_vtables[new_type] = new_vtable;
+    interpreter->vtables[new_type] = new_vtable;
+
+    /* check if we already have a NameSpace */
+    top = CONTEXT(interpreter->ctx)->current_namespace;
+    ns = VTABLE_get_pmc_keyed_str(interpreter, top, class_name);
+    /* XXX nested, use current as base ? */
+    if (!ns) {
+        /* XXX try HLL namespace too XXX */
+        parrot_context_t *ctx = CONTEXT(interpreter->ctx);
+        INTVAL hll_id = ctx->current_HLL;
+
+        top =  VTABLE_get_pmc_keyed_int(interpreter, 
+                interpreter->HLL_namespace, hll_id);
+        ns = VTABLE_get_pmc_keyed_str(interpreter, top, class_name);
+    }
+    if (!ns) {
+        ns = pmc_new(interpreter, enum_class_NameSpace);
+        VTABLE_set_pmc_keyed_str(interpreter, top, class_name, ns);
+    }
+    /* attach namspace to vtable */
+    new_vtable->_namespace = ns;
 
     /*
      * prepare object vtable - again that of the parent or
@@ -494,7 +519,7 @@ parrot_class_register(Interp* interpreter, STRING *class_name,
         parent_vtable = PMC_struct_val(vtable_pmc);
     }
     else
-        parent_vtable = Parrot_base_vtables[enum_class_ParrotObject];
+        parent_vtable = interpreter->vtables[enum_class_ParrotObject];
 
     new_vtable = Parrot_clone_vtable(interpreter, parent_vtable);
     new_vtable->base_type = new_type;
@@ -503,6 +528,8 @@ parrot_class_register(Interp* interpreter, STRING *class_name,
     set_attrib_num(new_class, (SLOTTYPE*)PMC_data(new_class), PCD_OBJECT_VTABLE,
             vtable_pmc = constant_pmc_new(interpreter, enum_class_VtableCache));
     PMC_struct_val(vtable_pmc) = new_vtable;
+    /* attach namspace to object vtable too */
+    new_vtable->_namespace = ns;
 }
 
 static PMC*
@@ -708,7 +735,8 @@ involved adding all the parent's parents, as well as all attributes of
 the parent classes that we're adding in.
 
 The MRO (method resolution order) is the C3 algorithm used by Perl6
-and Python (>= 2.3). See also L<http://use.perl.org/~autrijus/journal/25768>.
+and Python (>= 2.3). See also:
+L<http://pugs.blogs.com/pugs/2005/07/day_165_r5671_j.html>
 
 =cut
 
@@ -742,7 +770,7 @@ class_mro_merge(Interp* interpreter, PMC *seqs)
     while (1) {
         nseqs = not_empty(interpreter, seqs);
         if (!VTABLE_elements(interpreter, nseqs))
-            return res;
+            break;
         for (i = 0; i < VTABLE_elements(interpreter, nseqs); ++i) {
             seq = VTABLE_get_pmc_keyed_int(interpreter, nseqs, i);
             cand = VTABLE_get_pmc_keyed_int(interpreter, seq, 0);
@@ -980,7 +1008,7 @@ static void
 invalidate_all_caches(Interp *interpreter)
 {
     UINTVAL i;
-    for (i = 1; i < (UINTVAL)enum_class_max; ++i)
+    for (i = 1; i < (UINTVAL)interpreter->n_vtable_max; ++i)
         invalidate_type_caches(interpreter, i);
 }
 
@@ -1092,6 +1120,8 @@ debug_trace_find_meth(Interp* interpreter, PMC *class, STRING *name, PMC *sub)
 {
     STRING *class_name;
     const char *result;
+    Interp *tracer;
+
     if (!Interp_trace_TEST(interpreter, PARROT_TRACE_FIND_METH_FLAG))
         return;
     if (PObj_is_class_TEST(class)) {
@@ -1109,7 +1139,9 @@ debug_trace_find_meth(Interp* interpreter, PMC *class, STRING *name, PMC *sub)
     }
     else
         result = "no";
-    PIO_eprintf(interpreter,
+    tracer = interpreter->debugger ? 
+        interpreter->debugger : interpreter;
+    PIO_eprintf(tracer,
             "# find_method class '%Ss' method '%Ss': %s\n",
             class_name, name, result);
 }
@@ -1122,16 +1154,15 @@ static PMC *
 find_method_direct_1(Interp* interpreter, PMC *class,
                               STRING *method_name)
 {
-    PMC* method, *mro;
-    STRING *name;
+    PMC* method, *mro, *ns;
     INTVAL i, n;
 
     mro = class->vtable->mro;
     n = VTABLE_elements(interpreter, mro);
     for (i = 0; i < n; ++i) {
         class = VTABLE_get_pmc_keyed_int(interpreter, mro, i);
-        name = VTABLE_name(interpreter, class);
-        method = Parrot_find_global(interpreter, name, method_name);
+        ns = VTABLE_namespace(interpreter, class);
+        method = VTABLE_get_pmc_keyed_str(interpreter, ns, method_name);
         TRACE_FM(interpreter, class, method_name, method);
         if (method) {
             return method;
